@@ -5,9 +5,10 @@ import asyncio
 import json
 import logging
 
-import aioice
 import websockets
 
+import aioice
+
 STUN_SERVER = ("stun.l.google.com", 19302)
 WEBSOCKET_URI = "ws://127.0.0.1:8765"
 
@@ -34,9 +35,9 @@ async def offer(options):
     # await answer
     message = json.loads(await websocket.recv())
     print("received answer", message)
-    connection.remote_candidates = [
-        aioice.Candidate.from_sdp(c) for c in message["candidates"]
-    ]
+    for c in message["candidates"]:
+        await connection.add_remote_candidate(aioice.Candidate.from_sdp(c))
+    await connection.add_remote_candidate(None)
     connection.remote_username = message["username"]
     connection.remote_password = message["password"]
 
@@ -68,9 +69,9 @@ async def answer(options):
     # await offer
     message = json.loads(await websocket.recv())
     print("received offer", message)
-    connection.remote_candidates = [
-        aioice.Candidate.from_sdp(c) for c in message["candidates"]
-    ]
+    for c in message["candidates"]:
+        await connection.add_remote_candidate(aioice.Candidate.from_sdp(c))
+    await connection.add_remote_candidate(None)
     connection.remote_username = message["username"]
     connection.remote_password = message["password"]
 
