@@ -25,6 +25,5 @@ async def echo(websocket, path):
         clients.pop(client_id)
 
 
-asyncio.get_event_loop().run_until_complete(
-    websockets.serve(echo, '0.0.0.0', 8765))
+asyncio.get_event_loop().run_until_complete(websockets.serve(echo, "0.0.0.0", 8765))
 asyncio.get_event_loop().run_forever()
