@@ -198,8 +198,8 @@ class Message:
         transaction_id: Optional[bytes] = None,
         attributes: Optional[OrderedDict] = None,
     ) -> None:
-        self.message_method = Method(message_method)
-        self.message_class = Class(message_class)
+        self.message_method = message_method
+        self.message_class = message_class
         self.transaction_id = transaction_id or random_transaction_id()
         self.attributes = attributes or OrderedDict()
 
@@ -224,8 +224,8 @@ class Message:
                 v = attr_pack(attr_value)
 
             attr_len = len(v)
-            pad_len = 4 * ((attr_len + 3) // 4) - attr_len
-            data += pack("!HH", attr_type, attr_len) + v + (b"\x00" * pad_len)
+            pad_len = padding_length(attr_len)
+            data += pack("!HH", attr_type, attr_len) + v + bytes(pad_len)
         return (
             pack(
                 "!HHI12s",
@@ -238,10 +238,13 @@ class Message:
         )
 
     def __repr__(self) -> str:
-        return "Message(message_method=%s, message_class=%s, transaction_id=%s)" % (
-            self.message_method,
-            self.message_class,
-            repr(self.transaction_id),
+        return (
+            "Message(message_method=Method.%s, message_class=Class.%s, transaction_id=%s)"
+            % (
+                self.message_method.name,
+                self.message_class.name,
+                repr(self.transaction_id),
+            )
         )
 
 
@@ -314,6 +317,17 @@ class Transaction:
         self.__tries += 1
 
 
+def padding_length(length: int) -> int:
+    """
+    STUN message attributes are padded to a 4-byte boundary.
+    """
+    rest = length % 4
+    if rest == 0:
+        return 0
+    else:
+        return 4 - rest
+
+
 def parse_message(data: bytes, integrity_key: Optional[bytes] = None) -> Message:
     """
     Parses a STUN message.
@@ -333,7 +347,7 @@ def parse_message(data: bytes, integrity_key: Optional[bytes] = None) -> Message
     while pos <= len(data) - 4:
         attr_type, attr_len = unpack("!HH", data[pos : pos + 4])
         v = data[pos + 4 : pos + 4 + attr_len]
-        pad_len = 4 * ((attr_len + 3) // 4) - attr_len
+        pad_len = padding_length(attr_len)
         if attr_type in ATTRIBUTES_BY_TYPE:
             _, attr_name, attr_pack, attr_unpack = ATTRIBUTES_BY_TYPE[attr_type]
             if attr_unpack == unpack_xor_address:
@@ -351,9 +365,12 @@ def parse_message(data: bytes, integrity_key: Optional[bytes] = None) -> Message
                     raise ValueError("STUN message integrity does not match")
 
         pos += 4 + attr_len + pad_len
+
     return Message(
-        message_method=message_type & 0x3EEF,
-        message_class=message_type & 0x0110,
+        # An unknown method raises a `ValueError`.
+        message_method=Method(message_type & 0x3EEF),
+        # This cast cannot fail, as all 4 possible classes are defined.
+        message_class=Class(message_type & 0x0110),
         transaction_id=transaction_id,
         attributes=attributes,
     )
