@@ -1,10 +1,11 @@
 import asyncio
 import functools
 import os
-import socket
 import unittest
 from unittest import mock
 
+import ifaddr
+
 from aioice import Candidate, TransportPolicy, ice, mdns, stun
 
 from .turnserver import run_turn_server
@@ -44,7 +45,10 @@ class IceComponentTest(unittest.TestCase):
         connection = ice.Connection(ice_controlling=True)
         connection.remote_password = "remote-password"
         connection.remote_username = "remote-username"
+
         protocol = ProtocolMock()
+        protocol.response_addr = ("2.3.4.5", 2345)
+        protocol.response_message = "bad"
 
         request = stun.Message(
             message_method=stun.Method.BINDING, message_class=stun.Class.REQUEST
@@ -72,14 +76,13 @@ class IceComponentTest(unittest.TestCase):
         self.assertEqual(pair.remote_candidate, candidate)
 
         # check a triggered check was scheduled
-        self.assertIsNotNone(pair.handle)
-        protocol.response_addr = ("2.3.4.5", 2345)
-        protocol.response_message = "bad"
-        await pair.handle
+        self.assertIsNotNone(pair.task)
+        await pair.task
 
     @asynctest
     async def test_request_with_invalid_method(self):
         connection = ice.Connection(ice_controlling=True)
+
         protocol = ProtocolMock()
 
         request = stun.Message(
@@ -136,18 +139,39 @@ class IceConnectionTest(unittest.TestCase):
         ice.CONSENT_INTERVAL = 5
         stun.RETRY_MAX = 6
 
-    @mock.patch("netifaces.interfaces")
-    @mock.patch("netifaces.ifaddresses")
-    def test_get_host_addresses(self, mock_ifaddresses, mock_interfaces):
-        mock_interfaces.return_value = ["eth0"]
-        mock_ifaddresses.return_value = {
-            socket.AF_INET: [{"addr": "127.0.0.1"}, {"addr": "1.2.3.4"}],
-            socket.AF_INET6: [
-                {"addr": "::1"},
-                {"addr": "2a02:0db8:85a3:0000:0000:8a2e:0370:7334"},
-                {"addr": "fe80::1234:5678:9abc:def0%eth0"},
-            ],
-        }
+    @mock.patch("ifaddr.get_adapters")
+    def test_get_host_addresses(self, mock_get_adapters):
+        mock_get_adapters.return_value = [
+            ifaddr.Adapter(
+                ips=[
+                    ifaddr.IP(ip="127.0.0.1", network_prefix=8, nice_name="lo"),
+                    ifaddr.IP(ip=("::1", 0, 0), network_prefix=128, nice_name="lo"),
+                ],
+                name="lo",
+                nice_name="lo",
+            ),
+            ifaddr.Adapter(
+                ips=[
+                    ifaddr.IP(
+                        ip="1.2.3.4",
+                        network_prefix=24,
+                        nice_name="eth0",
+                    ),
+                    ifaddr.IP(
+                        ip=("2a02:0db8:85a3:0000:0000:8a2e:0370:7334", 0, 0),
+                        network_prefix=64,
+                        nice_name="eth0",
+                    ),
+                    ifaddr.IP(
+                        ip=("fe80::1234:5678:9abc:def0", 0, 2),
+                        network_prefix=64,
+                        nice_name="eth0",
+                    ),
+                ],
+                name="eth0",
+                nice_name="eth0",
+            ),
+        ]
 
         # IPv4 only
         addresses = ice.get_host_addresses(use_ipv4=True, use_ipv6=False)
@@ -228,8 +252,8 @@ class IceConnectionTest(unittest.TestCase):
         await conn_b.close()
         done, pending = await asyncio.wait(
             [
-                asyncio.ensure_future(conn_a.connect()),
-                asyncio.ensure_future(delay(conn_a.close)),
+                asyncio.create_task(conn_a.connect()),
+                asyncio.create_task(delay(conn_a.close)),
             ]
         )
         for task in pending:
@@ -552,8 +576,8 @@ class IceConnectionTest(unittest.TestCase):
         # connect
         done, pending = await asyncio.wait(
             [
-                asyncio.ensure_future(conn_a.connect()),
-                asyncio.ensure_future(conn_b.connect()),
+                asyncio.create_task(conn_a.connect()),
+                asyncio.create_task(conn_b.connect()),
             ],
             return_when=asyncio.FIRST_EXCEPTION,
         )
@@ -590,8 +614,8 @@ class IceConnectionTest(unittest.TestCase):
         # connect
         done, pending = await asyncio.wait(
             [
-                asyncio.ensure_future(conn_a.connect()),
-                asyncio.ensure_future(conn_b.connect()),
+                asyncio.create_task(conn_a.connect()),
+                asyncio.create_task(conn_b.connect()),
             ]
         )
         for task in pending:
@@ -1225,6 +1249,10 @@ class IceConnectionTest(unittest.TestCase):
             # we whould only have a server-reflexive candidate in connection a
             self.assertCandidateTypes(conn_a, set(["srflx"]))
 
+            # close
+            await conn_a.close()
+            await conn_b.close()
+
     @asynctest
     async def test_gather_candidates_relay_only_with_turn_server(self):
         async with run_turn_server(users={"foo": "bar"}) as turn_server:
@@ -1243,6 +1271,10 @@ class IceConnectionTest(unittest.TestCase):
             # we whould only have a server-reflexive candidate in connection a
             self.assertCandidateTypes(conn_a, set(["relay"]))
 
+            # close
+            await conn_a.close()
+            await conn_b.close()
+
     @asynctest
     async def test_repr(self):
         conn = ice.Connection(ice_controlling=True)
