@@ -3,7 +3,7 @@ import unittest
 
 from aioice import ice
 
-from .utils import run
+from .utils import asynctest
 
 
 class IceTrickleTest(unittest.TestCase):
@@ -11,17 +11,18 @@ class IceTrickleTest(unittest.TestCase):
         types = set([c.type for c in conn.local_candidates])
         self.assertEqual(types, expected)
 
-    def test_connect(self):
+    @asynctest
+    async def test_connect(self):
         conn_a = ice.Connection(ice_controlling=True)
         conn_b = ice.Connection(ice_controlling=False)
 
         # invite
-        run(conn_a.gather_candidates())
+        await conn_a.gather_candidates()
         conn_b.remote_username = conn_a.local_username
         conn_b.remote_password = conn_a.local_password
 
         # accept
-        run(conn_b.gather_candidates())
+        await conn_b.gather_candidates()
         conn_a.remote_username = conn_b.local_username
         conn_a.remote_password = conn_b.local_password
 
@@ -41,30 +42,28 @@ class IceTrickleTest(unittest.TestCase):
         async def add_candidates_later(a, b):
             await asyncio.sleep(0.1)
             for candidate in b.local_candidates:
-                a.add_remote_candidate(candidate)
+                await a.add_remote_candidate(candidate)
                 await asyncio.sleep(0.1)
-            a.add_remote_candidate(None)
+            await a.add_remote_candidate(None)
 
         # connect
-        run(
-            asyncio.gather(
-                conn_a.connect(),
-                conn_b.connect(),
-                add_candidates_later(conn_a, conn_b),
-                add_candidates_later(conn_b, conn_a),
-            )
+        await asyncio.gather(
+            conn_a.connect(),
+            conn_b.connect(),
+            add_candidates_later(conn_a, conn_b),
+            add_candidates_later(conn_b, conn_a),
         )
 
         # send data a -> b
-        run(conn_a.send(b"howdee"))
-        data = run(conn_b.recv())
+        await conn_a.send(b"howdee")
+        data = await conn_b.recv()
         self.assertEqual(data, b"howdee")
 
         # send data b -> a
-        run(conn_b.send(b"gotcha"))
-        data = run(conn_a.recv())
+        await conn_b.send(b"gotcha")
+        data = await conn_a.recv()
         self.assertEqual(data, b"gotcha")
 
         # close
-        run(conn_a.close())
-        run(conn_b.close())
+        await conn_a.close()
+        await conn_b.close()
